@@ -1,14 +1,15 @@
+import os
+import os.path as op
+
 from flask import Flask, request, session
 from flask_babelex import Babel
 from flask_sqlalchemy import SQLAlchemy
 
+from .data import build_sample_db
+
 app: Flask
 db: SQLAlchemy
 
-# app = Flask(__name__)
-# app.config.from_pyfile('config.py')
-# db = SQLAlchemy(app)
-
 
 def create_app(config_filename: str) -> Flask:
     global app
@@ -18,6 +19,15 @@ def create_app(config_filename: str) -> Flask:
     global db
     db = SQLAlchemy(app)
 
+    with app.app_context():
+        # Build a sample db on the fly, if one does not exist yet.
+        app_dir = op.join(
+            op.realpath(os.path.dirname(__file__)), "faker_file_admin"
+        )
+        database_path = op.join(app_dir, app.config["DATABASE_FILE"])
+        if not os.path.exists(database_path):
+            build_sample_db(db)
+
     return app
 
 
@@ -38,4 +48,4 @@ def get_locale():
     return session.get("lang", "en")
 
 
-import faker_file_admin.main
+import faker_file_admin.main  # noqa
