@@ -6,7 +6,7 @@ FLASK_ADMIN_SWATCH = "cerulean"
 SECRET_KEY = "123456790"
 
 # Create in-memory database
-DATABASE_FILE = "sample_db.sqlite"
+DATABASE_FILE = "../instance/sample_db.sqlite"
 SQLALCHEMY_DATABASE_URI = "sqlite:///" + DATABASE_FILE
 SQLALCHEMY_ECHO = True
 SQLALCHEMY_TRACK_MODIFICATIONS = False
